# frozen_string_literal: true

require 'yaml'

module Sorare
  module Rewards
    # Configuration stores the runtime configuration
    class Configuration
      attr_accessor :tiers, :gateway, :transform_tier, :transform_division,
                    :allocation_configuration, :prize_pool_configuration

      def initialize
        @tiers = 4
        @gateway = 'https://gateway.pinata.cloud/ipfs/'
        @transform_tier = ->(tier) { "tier_#{tier}" }
        @transform_division = ->(division) { "D#{division}" }
        @allocation_configuration = load_yaml_configuration_file('allocation_configuration.yml')['leagues']
        @prize_pool_configuration = load_yaml_configuration_file('prize_pool_configuration.yml')['rates']
      end

      def load_yaml_configuration_file(filename)
        YAML.safe_load(File.read("#{File.dirname(__FILE__)}/#{filename}"), [], [], true)
            .with_indifferent_access
      end
    end
  end
end
