# frozen_string_literal: true

require 'time'

module Sorare
  module Rewards
    # GameWeekConfig stores the config used to reward a game week
    class GameWeekConfig
      attr_reader :config

      def initialize(config)
        @config = config
      end

      %w[cooldown limits prize_pool_currency rewards_ratio_per_cards_in_circulation].each do |key|
        define_method(key) do
          config[key]
        end
      end

      def over_limit?(rarity, rewarded)
        limits[rarity] <= rewarded
      end

      def distribution_limit(rarity)
        limits[rarity] || 1
      end

      def cooldown_limit(rarity)
        cooldown.dig(rarity, 'quantity')
      end

      def cooldown_since(rarity)
        cooldown.dig(rarity, 'since')
      end
    end
  end
end
