# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'
require 'active_support/core_ext/enumerable'

module Sorare
  module Rewards
    module Allocations
      # ComputeForGameWeek computes the reward allocations for a game week given a supply and seed
      class ComputeForGameWeek
        include Interactor

        delegate :supply, :randomizer, :public_seed, :salt, to: :context

        def call
          context.randomizer = Sorare::Rewards::Random.new(public_seed, salt)
          context.game_week_allocations = allocations
        end

        def allocations
          supply.keys.index_with do |league|
            Allocations::ComputeForLeague.call!(
              **context.to_h, supply: supply[league], config: config[league]
            ).league_allocations
          end
        end

        def config
          Sorare::Rewards.configuration.allocation_configuration
        end
      end
    end
  end
end
