# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'
require 'active_support/core_ext/enumerable'

module Sorare
  module Rewards
    module Allocations
      # ComputeForLeague computes the reward allocations for a league given a supply and configuration
      class ComputeForLeague
        include Interactor

        delegate :supply, :config, to: :context

        def call
          context.league_allocations = allocate_and_format!
        end

        def allocate_and_format!
          each_rarity_allocation do |rarity|
            (allocations[rarity].first || {}).keys.index_with do |division|
              allocations[rarity].each_with_index.map do |qualified_allocations, tier|
                [Sorare::Rewards.configuration.transform_tier.call(tier), qualified_allocations[division]]
              end.to_h
            end
          end
        end

        def each_rarity_allocation(&block)
          allocations.keys.index_with(&block)
        end

        def allocations
          @allocations ||= (config || {}).keys.index_with do |rarity|
            ComputeForRarity.call!(**context.to_h, supply: supply[rarity], config: config[rarity]).rarity_allocations
          end
        end
      end
    end
  end
end
