# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'
require 'active_support/core_ext/enumerable'

module Sorare
  module Rewards
    module Allocations
      # ComputeForRarity computes the reward allocations for a rarity in a league
      class ComputeForRarity
        include Interactor

        delegate :supply, :config, to: :context

        def call
          context.fail!(error: 'Invalid config') unless config

          context.rarity_allocations = allocations
        end

        def allocations
          return [] unless supply

          supply.each_with_index.map do |tier_supply, tier|
            ComputeForQuality.call!(
              **context.to_h,
              supply: tier_supply,
              config: tier_config(tier)
            ).quality_allocations
          end
        end

        def tier_config(tier)
          config[Sorare::Rewards.configuration.transform_tier.call(tier)]
        end
      end
    end
  end
end
