# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    # Build builds the rewards structure for a given game week
    class Build
      include Interactor

      delegate :game_week, :salt, to: :context

      def call
        context.card_allocations = allocate!
        context.prize_pools = prize_pools!
        context.prize_pool_currency = game_week.config.prize_pool_currency
      end

      def game_week_supply
        @game_week_supply ||= Supply::ComputeForGameWeek.call!(game_week: game_week, salt: salt)
                                                        .game_week_supply
      end

      def allocate!
        Allocations::ComputeForGameWeek.call!(
          game_week: game_week, supply: game_week_supply, salt: salt
        ).game_week_allocations
      end

      def prize_pools!
        PrizePools::ComputeForGameWeek.call!(game_week: game_week, salt: salt).prize_pools
      end
    end
  end
end
