# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'
require 'active_support/core_ext/enumerable'
require 'yaml'

module Sorare
  module Rewards
    module Cards
      # PickForDivision picks the rewards for a given division
      # Receive a list of pickers for each tiers and quality
      #   {
      #     'rare' => { 'tier_0' => Picker, 'tier_1' => Picker },
      #     'super_rare' => { 'tier_0' => Picker, 'tier_1' => Picker }
      #   }
      # And a reward allocations
      #   {
      #     'rare' => [5, 15, 0, 0],
      #     'super_rare' => [1, 4, 0, 0],
      #     'unique' => [0, 0, 1, 0]
      #   }
      class PickForDivision
        include Interactor

        delegate :league, :allocations, :pickers, :qualified_players, to: :context

        def call
          context.cards_picked = allocations.keys.index_with do |rarity|
            PickForDivisionAndRarity.call!(
              **context.to_h,
              rarity: rarity,
              pickers: pickers[rarity],
              allocations: allocations[rarity]
            ).cards_picked
          end
        end
      end
    end
  end
end
