# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'
require 'active_support/core_ext/enumerable'

module Sorare
  module Rewards
    module Cards
      # PickForDivisionAndRarity picks the rewards for a given division and rarity
      # Receive a list of pickers for each tiers
      #   {
      #     'tier_0' => Picker, 'tier_1' => Picker
      #   }
      # A game week data
      # And a reward allocations
      #   { 'tier_0' => 1, 'tier_1' => 2 }
      class PickForDivisionAndRarity
        include Interactor

        delegate :league, :rarity, :allocations, :pickers, to: :context

        def call
          context.cards_picked = supply!
        end

        def supply!
          allocations.keys.index_with do |tier|
            next [] if pickers&.dig(tier).nil?

            PickForDivisionRarityAndQuality.call!(**context.to_h, allocations: allocations[tier],
                                                                  picker: pickers[tier]).cards_picked
          end
        end
      end
    end
  end
end
