# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module Cards
      # PickForDivisionRarityAndQuality picks the rewards for a given division, rarity, and quality
      # Receive a picker
      # A game week data
      # And a reward allocations
      #   15
      class PickForDivisionRarityAndQuality
        include Interactor

        MISSING_CARDS = 'There are not enough cards to fulfill the requirements'

        delegate :picker, :allocations, :league, :rarity, :force, :cards_picked, to: :context
        delegate :game_week, to: :league

        def call
          context.cards_picked = []

          pick!
          check_length! unless force
          reorder!
        end

        def pick!
          pick_if_available! while cards_picked.length != allocations && picker.length.positive?
        end

        def pick_if_available!
          player = picker.pick
          return if picker.player_counter[player] > game_week.player(player).pickable_supply(league, rarity)

          cards_picked.push(player)
        end

        def reorder!
          cards_picked.sort! do |a, b|
            game_week.player(a).rank(league, rarity) <=> game_week.player(b).rank(league, rarity)
          end
        end

        def check_length!
          return if cards_picked.length == allocations

          context.fail!(error: MISSING_CARDS)
        end
      end
    end
  end
end
