# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'
require 'active_support/core_ext/enumerable'

module Sorare
  module Rewards
    module Cards
      # PickForGameWeek picks the rewards for a given game week
      # Receive a Game Week object
      # And a reward allocations
      #    {
      #      'global-all_star' => {
      #        'D1' => {
      #          'rare' => { 'tier_0': 1, 'tier_1': 1 }
      #        }
      #      }
      #    }
      class PickForGameWeek
        include Interactor

        delegate :game_week, :allocations, :salt, :picks, to: :context

        def call
          context.cards_picked = pick!
        end

        def pick!
          allocations.each_league_allocations.each_with_object({}) do |(league_name, league_allocations), picks|
            picks[league_name] = PickForLeague.call!(
              **context.to_h, league: game_week.league(league_name), allocations: league_allocations
            ).cards_picked
          end
        end
      end
    end
  end
end
