# frozen_string_literal: true

require 'active_support/core_ext/enumerable'
require 'active_support/core_ext/hash/indifferent_access'
require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    # Pick the rewards for a given game week
    # Receive a Game Week reward supply data
    # And a reward allocations
    #    {
    #      'global-all_star' => {
    #        'rare' => {
    #          'D1' => { 'tier_0' => 0, 'tier_1' => 1 }
    #        }
    #      }
    #    }
    class Pick
      include Interactor

      delegate :card_allocations, :game_week, :salt, to: :context

      # Depending on the way the allocations interpreter is implemented it could be done by him or we
      # update the allocations process to match the structure
      def call
        context.cards_picked = Sorare::Rewards::Cards::PickForGameWeek.call!(
          **context.to_h,
          salt: salt,
          allocations: transposed_allocations
        ).cards_picked
      end

      def transposed_allocations
        Sorare::Rewards::GameWeekAllocations.new(Transposer.transpose_allocations(card_allocations))
      end
    end
  end
end
