# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module PrizePools
      # ComputeForDivision computes the prize pools of a division
      class ComputeForDivision
        include Interactor

        delegate :playing_rate, :available_prize_pools, to: :context

        def call
          context.division_prize_pools = available_prize_pools.map do |available_prize_pool|
            (available_prize_pool * percentage_rewarded).round(2)
          end
        end

        def percentage_rewarded
          @percentage_rewarded ||= (config.find do |rate_config|
            (rate_config.dig('playing_rates', 0)...rate_config.dig('playing_rates', 1)).include?(playing_rate)
          end || config.last)['percentage_rewarded']
        end

        def config
          Sorare::Rewards.configuration.prize_pool_configuration
        end
      end
    end
  end
end
