# frozen_string_literal: true

require 'active_support/core_ext/enumerable'
require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module PrizePools
      # ComputeForGameWeek computes the prize pools of a game week
      class ComputeForGameWeek
        include Interactor

        delegate :game_week, to: :context

        def call
          context.prize_pools = prize_pools!
        end

        def prize_pools!
          game_week.each_league.each_with_object(Hash.new({})) do |league, game_week_prize_pools|
            game_week_prize_pools[league.name] = ComputeForLeague.call!(league: league).league_prize_pools
          end
        end
      end
    end
  end
end
