# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module PrizePools
      # ComputeForLeague computes the prize pools of a league
      class ComputeForLeague
        include Interactor

        delegate :league, to: :context

        def call
          context.league_prize_pools = prize_pools!
        end

        def prize_pools!
          league.each_division_prize_pools.map do |division, prize_pools|
            [
              Sorare::Rewards.configuration.transform_division.call(division),
              ComputeForDivision.call!(playing_rate: league.playing_rate, available_prize_pools: prize_pools)
                                .division_prize_pools
            ]
          end.to_h
        end
      end
    end
  end
end
