# frozen_string_literal: true

require 'active_support/core_ext/enumerable'
require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module Supply
      # ComputeForGameWeek computes the rewardable supply of a game week based on the overall supply
      class ComputeForGameWeek
        include Interactor

        delegate :salt, :game_week, :game_week_supply, to: :context

        def call
          context.game_week_supply = game_week_supply!
        end

        def game_week_supply!
          game_week.each_league.each_with_object(Hash.new({})) do |league, game_week_supply|
            game_week_supply[league.name] = league_supply!(league)
          end
        end

        def league_supply!(league)
          league.each_rarity_supply.each_with_object({}) do |(rarity, supply), league_supply|
            league_supply[rarity] = ComputeForRarity.call!(
              league: league, rarity: rarity, supply: supply, randomizer: randomizer
            ).rarity_supply
          end
        end

        def randomizer
          @randomizer ||= Sorare::Rewards::Random.new(game_week.public_seed, salt)
        end
      end
    end
  end
end
