# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module Supply
      # ComputeForQuality computes the rewardable supply for a given quality between the divisions of a league
      class ComputeForQuality
        include Interactor

        delegate :randomizer, :total_supply, :tier_supply, :rewarded, :rewardable, to: :context

        def call
          context.quality_supply = total_supply.zero? ? 0 : quality_supply
        end

        def quality_supply
          plain, extra = (tier_supply.to_f * rewardable).divmod(total_supply)

          plain + remaining_supply(plain, extra)
        end

        def remaining_supply(plain, extra)
          reward_probability = randomizer.rand
          return 0 if rewarded.sum + plain >= rewardable
          return 0 if extra.zero?
          return 0 if reward_probability > (extra.to_f / total_supply)

          1
        end
      end
    end
  end
end
