# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    module Tiers
      # QualifySupply qualifies a supply sorted by rank in tiers
      # Returns an array of supply per tier
      class QualifySupply
        include Interactor

        delegate :sorted_supply, to: :context

        def call
          context.count = sorted_supply.values.sum { |p| p['supply'] }
          context.supply = qualified_supply
        end

        def qualified_supply
          return qualify! unless sorted_supply.values.first&.dig('tier')

          tiers = Array.new(Sorare::Rewards.configuration.tiers, 0)
          sorted_supply.each_value do |data|
            tiers[data['tier'].to_i] += data['supply']
          end

          tiers
        end

        def qualify!
          QualifyPlayers.call!(sorted_supply: sorted_supply).players.map do |tier_players|
            tier_players.sum { |p| sorted_supply[p]['supply'] }
          end
        end
      end
    end
  end
end
