# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    # League stores the reward config for a league
    class League
      attr_reader :name, :supply, :config, :game_week

      delegate :salt, to: :game_week

      def initialize(name:, config:, supply:, game_week:)
        @name = name
        @config = config
        @supply = supply
        @game_week = game_week
      end

      %w[playing_rate prize_pools cards_in_circulation].each do |key|
        define_method(key) do
          config[key]
        end
      end

      def cards_in_circulation_limit(rarity)
        return unless cards_in_circulation&.dig(rarity) && game_week.config.rewards_ratio_per_cards_in_circulation

        (cards_in_circulation[rarity] * game_week.config.rewards_ratio_per_cards_in_circulation).floor
      end

      def each_division_prize_pools
        prize_pools.each_with_index do |prize_pool, index|
          return to_enum(:each_division_prize_pools) unless block_given?

          yield(index + 1, prize_pool)
        end
      end

      def each_rarity_supply
        supply.each_key do |rarity|
          return to_enum(:each_rarity_supply) unless block_given?

          yield(rarity, supply[rarity])
        end
      end

      def each_rarity_tier_supply
        each_rarity_supply do |rarity, rarity_supply|
          qualified_supply = Tiers::QualifyPlayers.call!(sorted_supply: rarity_supply).players
          qualified_supply.each_key.map do |tier|
            return to_enum(:each_rarity_tier_supply) unless block_given?

            transformed_tier = Sorare::Rewards.configuration.transform_tier.call(tier)
            yield(rarity, transformed_tier, qualified_supply[tier])
          end
        end
      end
    end
  end
end
