# frozen_string_literal: true

require 'active_support/core_ext/module/delegation'

module Sorare
  module Rewards
    # Picker allows to randomly pick a card
    class Picker
      attr_accessor :cards, :player_counter

      delegate :length, to: :cards

      def initialize(seed, salt)
        @random = Random.new(seed, salt)
        @cards = []
        @player_counter = Hash.new(0)
        @shuffled = false
      end

      def add_player(slug, count)
        raise "Can't add a player to a started draw" if @shuffled

        @cards += Array.new(count, slug)
      end

      def pick
        shuffle! unless @shuffled

        @cards.shift.tap do |card|
          @player_counter[card] += 1 if card
        end
      end

      def shuffle!
        @cards.shuffle!(random: @random)
        @shuffled = true
      end
    end
  end
end
