# frozen_string_literal: true

require 'active_support/core_ext/enumerable'

module Sorare
  module Rewards
    # TransposeAllocations transposes the computed allocations
    # { 'league' => { 'rarity' => { 'division' => ... } } }
    # to a division based allocations
    # { 'league' => { 'division' => { 'rarity' => ... } } }
    module Transposer
      def self.transpose_allocations(allocations)
        allocations.keys.index_with do |league|
          transpose_league(allocations[league])
        end
      end

      def self.transpose_league(allocations)
        allocations.each_with_object({}) do |(rarity, league_allocations), hash|
          league_allocations.each do |division, supply|
            hash[division] = {} unless hash[division]
            hash[division][rarity] = supply
          end
        end
      end
    end
  end
end
